@@ -32,7 +32,8 @@ class MigrationLog(LoggerBuilder):
 
         keyword = "mig_log"
         level = MigrationProperties.log_config.level
-        handler = self.__get_log_handler(keyword)
+        log_size_mb = MigrationProperties.log_config.log_size_mb
+        handler = self.__get_log_handler(log_size_mb, keyword)
         formatter = self.__get_log_formatter()
         super(MigrationLog, self).__init__(keyword, level, handler, formatter)
 
@@ -48,18 +49,16 @@ class MigrationLog(LoggerBuilder):
         self.__validate_level(level)
 
     @staticmethod
-    def __get_log_handler(keyword):
+    def __get_log_handler(log_size_mb, keyword):
+        log_root = MigrationProperties.log_config.log_root
         log_dir = MigrationProperties.log_config.log_path
-        log_path = LoggerBuilder.create_log_file_path(os.getcwd(), log_dir, keyword)
-        log_size = 2*1024*1024  # 2MB
+        log_path = LoggerBuilder.create_log_file_path(log_root, log_dir, keyword)
+        log_size = int(log_size_mb)*1024*1024  # 10MB
         return logging.handlers.RotatingFileHandler(log_path, maxBytes=log_size, backupCount=10)
 
     @staticmethod
     def __get_log_formatter():
         return logging.Formatter('%(asctime)s %(levelname)-7s %(message)s', '%Y-%m-%d %H:%M:%S')
-        # return logging.Formatter('%(asctime)s %(levelname)-7s %(name)-7s %('
-        #                          'module)s:%(funcName)s:%(lineno)s -- %('
-        #                          'message)s', '%Y-%m-%d %H:%M:%S')
 
     @staticmethod
     def __validate_level(level):
@@ -200,3 +199,16 @@ class MigrationLog(LoggerBuilder):
     @staticmethod
     def log_exception(exception):
         MigrationLog.logger.exception(exception)
+
+    @staticmethod
+    def log_no_raw_processed_product(survey):
+        MigrationLog.logger.warning(f"No raw, processed, or product dataset found for survey {survey}. Survey will not be migrated.")
+
+    @staticmethod
+    def log_no_file_label_error(mb_file: MbFile):
+        MigrationLog.logger.error(f"no valid file label identified for file {mb_file.data_file} with ngdc_id {mb_file.ngdc_id}")
+
+    @staticmethod
+    def log_no_file_category_error(mb_file: MbFile):
+        MigrationLog.logger.error(f"no valid file category identified for file {mb_file.data_file} with ngdc_id {mb_file.ngdc_id}")
+
