@@ -1,8 +1,10 @@
+import datetime
 import unittest
 
 from src.mb_cruise_migration.db.cruise_db import CruiseDb
 from src.mb_cruise_migration.framework.parsed_data_file import ParsedFilePath
 from src.mb_cruise_migration.framework.file_decoder import FileDecoder
+from src.mb_cruise_migration.logging.migration_log import MigrationLog
 from tests.testutils import clean_cruise_db
 from src.mb_cruise_migration.migration_properties import MigrationProperties
 
@@ -37,6 +39,7 @@ class TestStandardMapping(unittest.TestCase):
 
     def test_standard(self):
         MigrationProperties("config_test.yaml")
+        MigrationLog()
 
         # PREP DB
         platform_service = PlatformService(CruiseDb())
@@ -74,8 +77,8 @@ class TestStandardMapping(unittest.TestCase):
         self.assertEqual("RR1808", survey.survey_name)
         self.assertIsNone(survey.parent)
         self.assertEqual("Roger Revelle", survey.platform_name)
-        self.assertEqual("13-JUN-18", survey.start_date)
-        self.assertEqual("17-JUN-18", survey.end_date)
+        self.assertEqual("2018-06-13T00:00:00", survey.start_date)
+        self.assertEqual("2018-06-17T00:00:00", survey.end_date)
         self.assertEqual("Newport, Oregon", survey.departure_port)
         self.assertEqual("Newport, Oregon", survey.arrival_port)
         self.assertIsNone(survey.creation_date)
@@ -421,8 +424,8 @@ class TestStandardMapping(unittest.TestCase):
             chief_scientist="Chadwell, C. David",
             departure_port="Newport, Oregon",
             arrival_port="Newport, Oregon",
-            start_time="13-JUN-18",
-            end_time="17-JUN-18",
+            start_time=datetime.datetime.strptime("13-JUN-18", "%d-%b-%y"),
+            end_time=datetime.datetime.strptime("17-JUN-18", "%d-%b-%y"),
             survey_name="RR1808",
             ship_name="Roger Revelle",
             source="Rolling Deck to Repository (R2R)",
